pub struct AssetClaimOutput {
pub asset_id: [u8; 32],
pub group_key: Option<SerializedKey>,
pub meta_hash: Option<[u8; 32]>,
pub proof_version: u32,
pub is_transfer_root: bool,
pub has_split_commitment: bool,
pub stxo_required: bool,
}Expand description
Output for the asset integrity claim.
Fields
asset_id: [u8; 32]Asset ID derived from genesis information.
group_key: Option<SerializedKey>Group key, if the asset is grouped.
meta_hash: Option<[u8; 32]>Meta hash, if one is set.
proof_version: u32Proof version committed by the claim.
is_transfer_root: boolTrue if the asset represents a transfer root.
has_split_commitment: boolTrue if the asset has a split commitment witness.
stxo_required: boolTrue if STXO proofs are required for this asset and proof version.